@@ -39,7 +39,7 @@
 
 struct preferences_state
 {
-  GtkObject *adj[3];
+  GObject *adj[3];
   GtkWidget *entry[3];
 };
 
@@ -51,9 +51,9 @@ pref_state_create (GtkBox * parent, const GbkGame * game)
 
   for (i = 0; i < 3; ++i)
     {
-      ps->adj[i] =
+      ps->adj[i] = G_OBJECT (
 	gtk_adjustment_new (gbk_cube_get_size (game->cube, 0), 1, G_MAXFLOAT,
-			    1, 1, 0);
+			    1, 1, 0));
       g_object_ref (ps->adj[i]);
       ps->entry[i] = gtk_spin_button_new (GTK_ADJUSTMENT (ps->adj[i]), 0, 0);
       g_object_ref (ps->entry[i]);
@@ -229,9 +229,9 @@ new_game_dialog (GtkWidget * w, GbkGame * game)
   gtk_box_pack_start (GTK_BOX (vbox), frame_pos, FALSE, 0, 0);
   gtk_box_pack_start (GTK_BOX (vbox), frame_dimensions, FALSE, 0, 0);
 
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
+  gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), vbox);
 
-  gtk_widget_show_all (GTK_DIALOG (dialog)->vbox);
+  gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG (dialog)));
 
   response = gtk_dialog_run (GTK_DIALOG (dialog));
 
