@@ -1,6 +1,6 @@
 /*
     routines which actually draw the blocks of the cube.
-    Copyright (C) 1998  John Darrington
+    Copyright (C) 1998, 2011  John Darrington
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,21 +18,14 @@
 #ifndef DRW_BLOCKS_H
 #define DRW_BLOCKS_H
 
-#include "cube.h"
 #include <GL/gl.h>
-#include "textures.h"
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include "cube.h"
+#include "cubeview.h"
+
+
 
 /* The texture names for each face */
-extern struct pattern_parameters face_patterns[6] ;
-
-void draw_block (GLboolean highlight,  int block_id);
-
-void setColour (int i,
-	       GLfloat red,
-	       GLfloat green,
-	       GLfloat  blue);
-
-void getColour (int i,  GLfloat *red,  GLfloat *green,  GLfloat *blue) ;
-
+void drawCube (GbkCube * cube, GLboolean ancilliary, GbkCubeview * cv);
 
 #endif
