@@ -1,6 +1,6 @@
 /*
     GNUbik -- A 3 dimensional magic cube game.
-    Copyright (C) 1998,  2003  John Darrington
+    Copyright (C) 1998,  2003, 2011  John Darrington
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,23 +20,6 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#define	checkImageWidth 64
-#define	checkImageHeight 64
-
-
-struct pattern_parameters
-{
-  GLuint texName;
-  GLubyte *data;
-  GLint texFunc;  /* This is the function to be passed to glTexEnv */
-};
-
-
-extern struct pattern_parameters stock_pattern[6];
-
-void texInit (void) ;
-
-
-GLuint create_pattern_from_pixbuf (const GdkPixbuf *pixbuf ,  GError **gerr);
+GLuint create_pattern_from_pixbuf (const GdkPixbuf * pixbuf, GError ** gerr);
 
 #endif
